if [ -x usr/bin/update-desktop-database ]; then
  usr/bin/update-desktop-database 1> /dev/null 2> /dev/null
fi

( cd usr/lib ; rm -rf libskinned.so.1 )
( cd usr/lib ; ln -sf libskinned.so.1.0.0 libskinned.so.1 )
( cd usr/lib ; rm -rf libskinned.so )
( cd usr/lib ; ln -sf libskinned.so.1.0.0 libskinned.so )
( cd usr/lib ; rm -rf libhrel.so.1 )
( cd usr/lib ; ln -sf libhrel.so.1.0.0 libhrel.so.1 )
( cd usr/lib ; rm -rf libhrel.so )
( cd usr/lib ; ln -sf libhrel.so.1.0.0 libhrel.so )
( cd usr/lib/bmpx/plugins/flow ; rm -rf libflow_linear.so.0 )
( cd usr/lib/bmpx/plugins/flow ; ln -sf libflow_linear.so.0.0.0 libflow_linear.so.0 )
( cd usr/lib/bmpx/plugins/flow ; rm -rf libflow_linear.so )
( cd usr/lib/bmpx/plugins/flow ; ln -sf libflow_linear.so.0.0.0 libflow_linear.so )
( cd usr/lib/bmpx/plugins/flow ; rm -rf libflow_shuffle.so.0 )
( cd usr/lib/bmpx/plugins/flow ; ln -sf libflow_shuffle.so.0.0.0 libflow_shuffle.so.0 )
( cd usr/lib/bmpx/plugins/flow ; rm -rf libflow_shuffle.so )
( cd usr/lib/bmpx/plugins/flow ; ln -sf libflow_shuffle.so.0.0.0 libflow_shuffle.so )
( cd usr/lib/bmpx/plugins/transport ; rm -rf libtransport_cdda.so.0 )
( cd usr/lib/bmpx/plugins/transport ; ln -sf libtransport_cdda.so.0.0.0 libtransport_cdda.so.0 )
( cd usr/lib/bmpx/plugins/transport ; rm -rf libtransport_cdda.so )
( cd usr/lib/bmpx/plugins/transport ; ln -sf libtransport_cdda.so.0.0.0 libtransport_cdda.so )
( cd usr/lib/bmpx/plugins/transport ; rm -rf libtransport_file.so.0 )
( cd usr/lib/bmpx/plugins/transport ; ln -sf libtransport_file.so.0.0.0 libtransport_file.so.0 )
( cd usr/lib/bmpx/plugins/transport ; rm -rf libtransport_file.so )
( cd usr/lib/bmpx/plugins/transport ; ln -sf libtransport_file.so.0.0.0 libtransport_file.so )
( cd usr/lib/bmpx/plugins/transport ; rm -rf libtransport_http.so.0 )
( cd usr/lib/bmpx/plugins/transport ; ln -sf libtransport_http.so.0.0.0 libtransport_http.so.0 )
( cd usr/lib/bmpx/plugins/transport ; rm -rf libtransport_http.so )
( cd usr/lib/bmpx/plugins/transport ; ln -sf libtransport_http.so.0.0.0 libtransport_http.so )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_folder.so.0 )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_folder.so.0.0.0 libcontainer_folder.so.0 )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_folder.so )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_folder.so.0.0.0 libcontainer_folder.so )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_m3u.so.0 )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_m3u.so.0.0.0 libcontainer_m3u.so.0 )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_m3u.so )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_m3u.so.0.0.0 libcontainer_m3u.so )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_pls.so.0 )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_pls.so.0.0.0 libcontainer_pls.so.0 )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_pls.so )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_pls.so.0.0.0 libcontainer_pls.so )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_xspf.so.0 )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_xspf.so.0.0.0 libcontainer_xspf.so.0 )
( cd usr/lib/bmpx/plugins/container ; rm -rf libcontainer_xspf.so )
( cd usr/lib/bmpx/plugins/container ; ln -sf libcontainer_xspf.so.0.0.0 libcontainer_xspf.so )
( cd usr/share/pixmaps ; rm -rf bmpx.png )
( cd usr/share/pixmaps ; ln -sf ../icons/hicolor/48x48/apps/bmpx.png bmpx.png )
