/*  libhrel - Holyrel library

    Copyright (C) 2005 Chong Kai Xiong <descender@phreaker.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA  02111-1307  USA.
*/

#ifndef H_MISC_H
#define H_MISC_H

#include <glib.h>
#include <stdarg.h>

G_BEGIN_DECLS

GSList *h_va_list_to_slist (va_list  args);
GSList *h_string_list_copy (GSList  *list);
void    h_string_list_free (GSList  *list);

G_END_DECLS

#endif /* #ifndef H_MISC_H */
