#ifndef _BMP_DBUS_H
#define _BMP_DBUS_H

// Web URL: http://beep-media-player.org/index.php/MPRIS

#define BMP_DBUS_SERVICE            "org.mpris.bmpx"
#define BMP_DBUS_INTERFACE          BMP_DBUS_SERVICE
#define BMP_DBUS_PATH               "/org/mpris/bmpx"
#define BMP_DBUS_PATH_SYSTEMCONTROL BMP_DBUS_PATH "/SystemControl"


typedef enum {
    
	BMP_DBUS_ERROR_INVALID_URI,
	BMP_DBUS_ERROR_INVALID_LIST,
	BMP_DBUS_ERROR_LIST_EXISTS,

	BMP_DBUS_ERROR_INTERNAL_ERROR
	
} BmpDBusError;

#endif /* _BMP_BUS_H */
