#ifndef _PLUGIN_INTERFACES_H_ 
#define _PLUGIN_INTERFACES_H_ 

#include <glib-object.h>

#include "bmpx/interfaces/plugin_interface_flow.h"
#include "bmpx/interfaces/plugin_interface_transport.h"
#include "bmpx/interfaces/plugin_interface_container.h"
#include "bmpx/interfaces/plugin_interface_plug_meta.h"

#endif /* _PLUGIN_INTERFACES_H_ */










