/* BMP - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * Themes added by The Rasterman <raster@redhat.com>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * Modified by the BMP+ Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the BMP+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * BMP+ at ftp://ftp.bmp.org/pub/bmp/. 
 */

#ifndef __BMP_THEMES_H__
#define __BMP_THEMES_H__

#include <config.h>

#include <glib.h>
#include <glib-object.h>

#include "bmpx/plugin.h"
#include "bmpx/plugin_interfaces.h"

G_BEGIN_DECLS

#define BMP_TYPE_PLUGIN             (bmp_plugin_get_type ())
#define BMP_PLUGIN(plugin)	    (G_TYPE_CHECK_INSTANCE_CAST ((plugin), BMP_TYPE_PLUGIN, BmpPlugin))
#define BMP_IS_PLUGIN(plugin)	    (G_TYPE_CHECK_INSTANCE_TYPE ((plugin), BMP_TYPE_PLUGIN))

typedef struct _BmpPlugin BmpPlugin;

GType           bmp_plugin_get_type        (void) G_GNUC_CONST;

BmpPlugin*	bmp_plugin_new		   (const gchar *path);
gboolean	bmp_plugin_valid	   (BmpPlugin *plugin);
GObject*	bmp_plugin_create_instance (BmpPlugin *plugin);

 
G_END_DECLS

#endif /* __BMP_THEMES_H__ */
