/*  libhrel - Holyrel library

    Copyright (C) 2005 Chong Kai Xiong <descender@phreaker.net>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA  02111-1307  USA.
*/

#ifndef H_HASH_INDEX_H
#define H_HASH_INDEX_H

#include <glib.h>
#include "tuple.h"

G_BEGIN_DECLS

typedef void (*HIndexFunc) (HTuple   *tuple,
                            gpointer  value,
                            gpointer  user_data);

typedef struct _HHashIndex HHashIndex;

HHashIndex *h_hash_index_new       (GDestroyNotify  key_destroy_func,
                                    GDestroyNotify  value_destroy_func,
                                    ...);
HHashIndex *h_hash_index_new_l     (GDestroyNotify  key_destroy_func,
                                    GDestroyNotify  value_destroy_func,
                                    GSList         *list);
void        h_hash_index_free      (HHashIndex     *index);
GSList     *h_hash_index_get_attrs (HHashIndex     *index);
gpointer    h_hash_index_lookup    (HHashIndex     *index,
                                    HTuple         *tuple);
void        h_hash_index_insert    (HHashIndex     *index,
                                    HTuple         *tuple,
                                    gpointer        value);
gboolean    h_hash_index_remove    (HHashIndex     *index,
                                    HTuple         *tuple);
guint       h_hash_index_get_size  (HHashIndex     *index);
void        h_hash_index_foreach   (HHashIndex     *index,
                                    HIndexFunc      func,
                                    gpointer        user_data);

G_END_DECLS


#endif /* #ifndef H_HASH_INDEX_H */

